__version__ = "0.5.1.dev8"
__long_desc__ = """
# Swarmauri Core

## Core 
- **Core Interfaces**: Define the fundamental communication and data-sharing protocols between components in a Swarmauri-based system.


Visit us at: https://swarmauri.com
Follow us at: https://github.com/swarmauri 



"""
